@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -315,7 +315,16 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
         ContentTypeField[] fields = destination.getContentType().getFields();
         for (int i = 0; i < len; i++) {
             if (requestedFields.get(i)) {
+                String fieldName = fields[i].getFieldName();
                 updateDataObjectFieldFromJSONArray(array, j, fields[i], destination);
+
+                if (fieldName.equals(ContactConstants.EMAIL1) || fieldName.equals(ContactConstants.EMAIL2) || fieldName.equals(ContactConstants.EMAIL3)) {
+                    Object fieldValue = destination.getFieldContent(fieldName);
+                    // Bug 42844: filter email addresses consisting of whitespaces only
+                    if (fieldValue != null && fieldValue instanceof String && ((String) fieldValue).trim().isEmpty()) {
+                        destination.setFieldContent(fieldName, null);
+                    }
+                }
                 if (fields[i].getFieldID() == ContactContentTypeImpl.IMAGE1_FIELD_ID)
                     j += 3;
                 else
