@@ -245,13 +245,13 @@ public class MailContentTypeImpl extends AbstractContentType implements MailCont
     }
 
     @Override
-    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields) throws USMException {
-        return _transferHandler.searchMails(searchCriteria, folderId, session, requestedFields);
+    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException {
+        return _transferHandler.searchMails(searchCriteria, folderId, session, requestedFields, firstMatch, lastMatch);
     }
 
     @Override
-    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields) throws USMException {
-        return _transferHandler.searchMails(searchText, folderId, session, requestedFields);
+    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException {
+        return _transferHandler.searchMails(searchText, folderId, session, requestedFields, firstMatch, lastMatch);
     }
 
     @Override
