@@ -712,18 +712,22 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         return conversionObject;
     }
 
-    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields) throws USMException {
+    public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         parameters.put(CommonConstants.FOLDER, folderId);
-        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_ALL, session, parameters, searchCriteria);
+        parameters.put(LEFT_HAND_LIMIT, String.valueOf(firstMatch));
+        parameters.put(RIGHT_HAND_LIMIT, String.valueOf(lastMatch));
+        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_SEARCH, session, parameters, searchCriteria);
         return buildSearchResultList(session, requestedFields, jResult);
     }
 
-    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields) throws USMException {
+    public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields, int firstMatch, int lastMatch) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         parameters.put(CommonConstants.FOLDER, folderId);
+        parameters.put(LEFT_HAND_LIMIT, String.valueOf(firstMatch));
+        parameters.put(RIGHT_HAND_LIMIT, String.valueOf(lastMatch));
         JSONObject searchCriteria = new JSONObject();
         JSONArray searchArray = new JSONArray();
         try {
