@@ -51,24 +51,30 @@ package com.openexchange.usm.contenttypes.resources.impl;
 
 import static com.openexchange.usm.api.datatypes.DataTypes.BOOLEAN;
 import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
+import java.util.BitSet;
 import com.openexchange.usm.api.contenttypes.common.CommonConstants;
 import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
 import com.openexchange.usm.api.contenttypes.resource.ResourceContentType;
 import com.openexchange.usm.api.contenttypes.resource.ResourcesConstants;
 import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
+import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
+import com.openexchange.usm.api.exceptions.InternalUSMException;
+import com.openexchange.usm.api.exceptions.OXCommunicationException;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractContentType;
 
 public class ResourcesContentTypeImpl extends AbstractContentType implements ResourceContentType {
 
     private static final ContentTypeField[] FIELDS = {
-        new ContentTypeField(-1900, CommonConstants.FIELD_ID, STRING, false, true, false, false), // ID
+        new ContentTypeField(0, CommonConstants.FIELD_ID, STRING, false, true, false, false), // ID
         new ContentTypeField(-1901, CommonConstants.FOLDER_ID, STRING, false, false, true, false), // Object ID of the parent folder. Dummy
                                                                                                    // field. Always empty
-        new ContentTypeField(-1902, ResourcesConstants.DISPLAY_NAME, STRING), // Display Name
+        new ContentTypeField(2, ResourcesConstants.DISPLAY_NAME, STRING), // Display Name
         new ContentTypeField(-1903, ResourcesConstants.NAME, STRING), // internal Name
-        new ContentTypeField(-1904, ResourcesConstants.MAIL_ADDRESS, STRING), // email address
+        new ContentTypeField(4, ResourcesConstants.MAIL_ADDRESS, STRING), // email address
         new ContentTypeField(-1905, ResourcesConstants.AVAILABILITY, BOOLEAN), // availability
         new ContentTypeField(-1906, ResourcesConstants.DESCRIPTION, STRING), // description
     };
@@ -104,6 +110,18 @@ public class ResourcesContentTypeImpl extends AbstractContentType implements Res
         _transferHandler = transferHandler;
     }
 
+    @Override
+    public DataObject[] getAllResources(Session session, BitSet requestedFields) throws AuthenticationFailedException,
+            OXCommunicationException, UnsupportedContentOperationException, InternalUSMException {
+        return _transferHandler.getAllResources(session, requestedFields);
+    }
+
+    @Override
+    public void getResource(DataObject object, BitSet requestedFields) throws AuthenticationFailedException,
+            OXCommunicationException, InternalUSMException, UnsupportedContentOperationException {
+        _transferHandler.getResource(object, requestedFields);
+    }
+
     @Override
     public boolean supportsPIMAttachments() {
         return false;
