@@ -105,9 +105,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     protected static final String _LAST_MODIFIED_COLUMN = "5";
 
-    private static final String RIGHT_HAND_LIMIT = "right_hand_limit";
+    protected static final String RIGHT_HAND_LIMIT = "right_hand_limit";
 
-    private static final String LEFT_HAND_LIMIT = "left_hand_limit";
+    protected static final String LEFT_HAND_LIMIT = "left_hand_limit";
 
     private static final String ERROR_PARAMS = "error_params";
 
