@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -424,6 +424,15 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         return isAppointmentException(dataObject);
     }
 
+    protected static boolean isFolder(DataObject dataObject) {
+        if(dataObject == null)
+            return false;
+        ContentType contentType = dataObject.getContentType();
+        if (contentType == null || contentType.getCode() != DefaultContentTypes.FOLDER_CODE)
+            return false;
+        return true;
+    }
+
     protected void addOptionalFolderUUID(DataObject o, JSONObject object) throws USMJSONAPIException, JSONException {
         if (object.has(FOLDER_ID)) {
             initAllFolders();
