@@ -54,14 +54,22 @@ import com.openexchange.usm.api.session.OXConnectionInformation;
 
 public class OXConnectionData implements OXConnectionInformation {
 
+    private static final long serialVersionUID = -210011280973132893L;
+
     private final String _sessionID;
 
+    private final int userId;
+
+    private final int contextId;
+
     private final HttpClient _httpClient;
 
     private ResourceInputStreamImpl _currentResourceInputStream;
 
-    public OXConnectionData(String sessionID, HttpClient client) {
+    public OXConnectionData(String sessionID, int userId, int contextId, HttpClient client) {
         _sessionID = sessionID;
+        this.userId = userId;
+        this.contextId = contextId;
         _httpClient = client;
     }
 
@@ -85,4 +93,22 @@ public class OXConnectionData implements OXConnectionInformation {
     public void setCurrentResourceInputStream(ResourceInputStreamImpl currentResourceInputStream) {
         _currentResourceInputStream = currentResourceInputStream;
     }
+
+    /**
+     * Gets the userId
+     *
+     * @return The userId
+     */
+    public int getUserId() {
+        return userId;
+    }
+
+    /**
+     * Gets the contextId
+     *
+     * @return The contextId
+     */
+    public int getContextId() {
+        return contextId;
+    }
 }
