@@ -59,7 +59,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
-
 import org.apache.commons.httpclient.Header;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpException;
@@ -91,7 +90,6 @@ import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
@@ -289,7 +287,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 result.toString());
         try {
             String sessionID = result.getJSONObject().getString("session");
-            OXConnectionData data = new OXConnectionData(sessionID, client);
+            int userId = result.getJSONObject().getInt("user_id");
+            int contextId = result.getJSONObject().getInt("context_id");
+            OXConnectionData data = new OXConnectionData(sessionID, userId, contextId, client);
             session.setOXConnectionData(data);
             return data;
         } catch (JSONException e) {
