@@ -74,6 +74,8 @@ public class USMActive extends AbstractModules {
      */
     @Override
     protected boolean getModule(final UserConfiguration userConfig) {
-        return userConfig.hasUSM();
+        if (userConfig != null)
+            return userConfig.hasUSM();
+        return false;
     }
 }
