@@ -1011,9 +1011,12 @@ public class SessionImpl implements Session {
                     for (String id : contentChangeParentIDsToWatch) {
                         _syncedFolderContent.put(id, 0L);
                     }
-                    return null;
+                    watchFolderChanges = false;
+                    // do not return immediately, because this could lead to a frequent ping loop (see bug 48696)
+                    // continue with waiting
                 }
-                return result;
+                else
+                    return result;
             }
         }
         _directPingResponses = 0;
