@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.exceptions.ConflictingChange;
 import com.openexchange.usm.api.exceptions.ConflictingChangeException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
@@ -72,6 +74,7 @@ import com.openexchange.usm.api.session.exceptions.SlowSyncRequiredException;
 import com.openexchange.usm.api.session.exceptions.SynchronizationConflictException;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
+import com.openexchange.usm.session.dataobject.FieldMapStorageImpl;
 import com.openexchange.usm.session.impl.SessionManagerImpl;
 import com.openexchange.usm.session.impl.USMSessionManagementErrorCodes;
 
@@ -196,8 +199,13 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 				}
 				if (cf != null) {
 					// if modified, store modification
-					if (!sf.equals(cf))
-						serverModifications.add(DataObjectUtil.copyAndModify(cf, sf, true));
+					if (!sf.equals(cf)) {
+                        DataObject serverModify = DataObjectUtil.copyAndModify(cf, sf, true);
+						serverModifications.add(serverModify);
+						if (_journal.isTraceEnabled()) {
+						    _journal.trace("syncChangesWithServer copyAndModify: " + serverModify.toString());
+						}
+                    }
 					sf.linkUUIDTo(cf);
 					i.remove(); // found -> remove from list of server creations
 					clientDataObjects.remove(cf); // and from temporary list of old objects which will become the list of deletions
@@ -209,6 +217,9 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 			// Create list of relevant client requests, i.e. only those for DataObjects that have not been deleted on the server
 			DataObjectSet serverObjectsWithUUID = new DataObjectSet(serverDataObjects);
 			for (DataObject f : dataObjectChanges) {
+			    if (_journal.isTraceEnabled()) {
+			        _journal.trace("syncChangesWithServer clientChange: " + f.toString());
+			    }
 				if (!isDuplicateCreation(serverObjectsWithUUID, f, serverCreations, cachedDataObjects)) {
 					DataObject serverDeletion = serverDeletions.get(f.getID());
 					if (serverDeletion == null)
@@ -415,7 +426,9 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 				return;
 			case MODIFIED:
 				serverChange = serverModifications.get(f.getID());
-				if (serverChange == null) {
+				if (serverChange == null || isClientChangeWithServerCompatible(f, serverChange)) {
+				    if (_journal.isTraceEnabled())
+		                _journal.trace("newServerModification: " + f.toString());
 					newServerModifications.add(f);
 					return;
 				}
@@ -427,6 +440,26 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 				"Illegal ChangeState " + f.getChangeState());
 	}
 
+	// check whether modified fields on the server are already contained in the client change
+	private boolean isClientChangeWithServerCompatible(DataObject f, DataObject serverChange) {
+        ContentTypeField[] fields = f.getContentType().getFields();
+        Integer lastModifiedIndex = FieldMapStorageImpl.getInstance().getFieldNameToIndexMap(f.getContentType()).get("last_modified");
+        if (lastModifiedIndex == null)
+            lastModifiedIndex = -1;
+
+        for (int i = 0; i < fields.length; i++) {
+            if (i == lastModifiedIndex)
+                continue;
+            DataType<?> type = fields[i].getFieldType();
+            if (serverChange.isFieldModified(i)) {
+                if (!type.isEqual(f.getFieldContent(i), serverChange.getFieldContent(i)))
+                    return false;
+            }
+        }
+
+	    return true;
+	}
+	
 	private void handleConflictingModifications(ConflictResolution conflictResolution,
 			DataObjectSet serverModifications, List<ConflictingChange> conflicts,
 			List<DataObject> newServerModifications, DataObject f, DataObject serverChange) throws InternalUSMException {
