@@ -63,6 +63,7 @@ import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.usm.api.database.DatabaseAccess;
+import com.openexchange.usm.api.database.DatabaseAccessWithNoTimeoutSupport;
 import com.openexchange.usm.api.database.EncapsulatedConnection;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.USMStorageException;
@@ -76,7 +77,7 @@ import com.openexchange.usm.util.Toolkit;
 
 /**
  * {@link PersistentSessionDataStorageSQL}
- * 
+ *
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
 public class PersistentSessionDataStorageSQL implements PersistentSessionDataStorage {
@@ -93,7 +94,7 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
 
     /**
      * Initializes a new {@link PersistentSessionDataStorageSQL}.
-     * 
+     *
      * @param Access
      */
     public PersistentSessionDataStorageSQL(DatabaseAccess dba) {
@@ -107,10 +108,11 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
      */
     @Override
     public void storeFieldValue(Session session, String key, String value) throws USMStorageException, StorageAccessException {
-        if(dbAccess.supportsOnDuplicateKeyUpdateStatement())
+        if(dbAccess.supportsOnDuplicateKeyUpdateStatement()) {
             insertOnDuplicateKeyUpdateField(session, key, value);
-        else
+        } else {
             insertOrUpdateField(session, key, value);
+        }
     }
 
     private void insertOnDuplicateKeyUpdateField(Session session, String key, String value) throws USMStorageException, StorageAccessException {
@@ -124,8 +126,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             statement.setString(4, value);
             statement.setString(5, value);
 
-            if (statement.executeUpdate() == 0)
+            if (statement.executeUpdate() == 0) {
                 LOG.warn(session + " Setting field " + key + " in DB did not change any rows");
+            }
 
         } catch (SQLException e) {
             String errorMessage = session + " SQL error while updating field " + key;
@@ -165,8 +168,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
                 statement.setString(3, key);
                 statement.setString(4, value);
             }
-            if (statement.executeUpdate() != 1)
+            if (statement.executeUpdate() != 1) {
                 LOG.warn(session + " Setting field " + key + " in DB did not change any rows");
+            }
             con.commit();
         } catch (SQLException e) {
             String errorMessage = session + " SQL error while updating field " + key;
@@ -239,8 +243,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             statement.setInt(1, session.getContextId());
             statement.setInt(2, session.getSessionId());
             statement.setString(3, key);
-            if (statement.executeUpdate() != 1)
+            if (statement.executeUpdate() != 1) {
                 LOG.warn(session + " Deleting field " + key + " in DB did not change any rows");
+            }
         } catch (SQLException e) {
             String errorMessage = session + " SQL error while updating field " + key;
             throw new USMStorageException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_ERROR_NUMBER2, errorMessage, e);
@@ -276,8 +281,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             statement.setInt(1, session.getContextId());
             statement.setInt(2, session.getSessionId());
 
-            if (statement.executeUpdate() != 1)
+            if (statement.executeUpdate() != 1) {
                 LOG.warn(session + " Deleting session in DB did not change any rows");
+            }
 
         } catch (SQLException e) {
             String errorMessage = session + " SQL error while deleting fields ";
@@ -425,11 +431,19 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
         if (sessionIDs.isEmpty()) {
             return 0;
         }
+
+        EncapsulatedConnection con = dbAccess instanceof DatabaseAccessWithNoTimeoutSupport ? ((DatabaseAccessWithNoTimeoutSupport) dbAccess).getNoTimeout(contextID) : dbAccess.getWritable(contextID);
+        try {
+            return purgeSessions(contextID, sessionIDs, con);
+        } finally {
+            Toolkit.close(con);
+        }
+    }
+
+    private int purgeSessions(int contextID, Set<ContextSessionID> sessionIDs, EncapsulatedConnection con) {
         int count = 0;
-        EncapsulatedConnection con = null;
         PreparedStatement[] stmts = new PreparedStatement[USM_TABLES.length];
         try {
-            con = dbAccess.getWritable(contextID);
             for (int i = 0; i < USM_TABLES.length; i++) {
                 stmts[i] = con.prepareStatement("DELETE FROM " + USM_TABLES[i] + " WHERE cid = ? AND usmSessionId = ?");
             }
@@ -451,7 +465,6 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             for (PreparedStatement s : stmts) {
                 Toolkit.close(s);
             }
-            Toolkit.close(con);
         }
         return count;
     }
@@ -521,8 +534,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
                 rs = stmt.executeQuery();
                 if (rs.next()) {
                     long syncKey = rs.getLong(1);
-                    if (syncKey < specialLimit)
+                    if (syncKey < specialLimit) {
                         sessionIDsToRemove.add(sessionID);
+                    }
                 } else {
                     // No SyncState at all -> can be safely removed
                     sessionIDsToRemove.add(sessionID);
@@ -592,8 +606,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             List<SessionInformation> sessionList = new ArrayList<SessionInformation>(sessionIDs.values());
             Collections.sort(sessionList);
             List<String> returnData = new ArrayList<String>();
-            for (SessionInformation si : sessionList)
+            for (SessionInformation si : sessionList) {
                 si.appendFieldDataToList(returnData);
+            }
             return returnData;
         } catch (SQLException e) {
             String errorMessage = cid + ": Error while retrieving session fields.";
@@ -622,8 +637,9 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
             try {
                 sessionIDs = retrieveUSMSessionsFromDB(cid, id, protocol, device, con, validContextIDs);
                 statement = con.prepareStatement("DELETE FROM USMSessionFields WHERE cid = ? AND usmSessionId = ? AND field = ?");
-                if (isParameterSet(value))
+                if (isParameterSet(value)) {
                     insertStatement = con.prepareStatement("INSERT INTO USMSessionFields (cid, usmSessionId, Field, Value) VALUES(?,?,?,?)");
+                }
                 for (USMSessionID usmId : sessionIDs.keySet()) {
                     statement.setInt(1, usmId.getCID());
                     statement.setInt(2, usmId.getUSMSessionID());
@@ -677,7 +693,7 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
 
     /**
      * Retrieves USM sessions from the DB for the given parameters
-     * 
+     *
      * @param cid
      * @param id
      * @param protocol
@@ -693,24 +709,32 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
         try {
             StringBuilder selectSessionQuery = new StringBuilder("SELECT cid, id, protocol, device, usmSessionId FROM USMSession");
             boolean first = true;
-            if (cid != 0)
+            if (cid != 0) {
                 first = appendConditionToQuery(selectSessionQuery, "cid", first);
-            if (id != 0)
+            }
+            if (id != 0) {
                 first = appendConditionToQuery(selectSessionQuery, "id", first);
-            if (isParameterSet(device))
+            }
+            if (isParameterSet(device)) {
                 first = appendConditionToQuery(selectSessionQuery, "device", first);
-            if (isParameterSet(protocol))
+            }
+            if (isParameterSet(protocol)) {
                 first = appendConditionToQuery(selectSessionQuery, "protocol", first);
+            }
             statement = con.prepareStatement(selectSessionQuery.toString());
             int paramCount = 0;
-            if (cid != 0)
+            if (cid != 0) {
                 statement.setInt(++paramCount, cid);
-            if (id != 0)
+            }
+            if (id != 0) {
                 statement.setInt(++paramCount, id);
-            if (isParameterSet(device))
+            }
+            if (isParameterSet(device)) {
                 statement.setString(++paramCount, device);
-            if (isParameterSet(protocol))
+            }
+            if (isParameterSet(protocol)) {
                 statement.setString(++paramCount, protocol);
+            }
             result = statement.executeQuery();
             Map<USMSessionID, SessionInformation> sessionIDs = new HashMap<USMSessionID, SessionInformation>();
             while (result.next()) {
@@ -731,24 +755,25 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
 
     /**
      * Applies either a WHERE or an AND condition to the given query
-     * 
+     *
      * @param builder
      * @param dbColumn
      * @param first
      * @return
      */
     private static boolean appendConditionToQuery(StringBuilder builder, String dbColumn, boolean first) {
-        if (first)
+        if (first) {
             builder.append(" WHERE ");
-        else
+        } else {
             builder.append(" AND ");
+        }
         builder.append(dbColumn).append(" = ?");
         return false;
     }
 
     /**
      * Verifies whether the given parameter is set.
-     * 
+     *
      * @param param
      * @return
      */
@@ -758,7 +783,7 @@ public class PersistentSessionDataStorageSQL implements PersistentSessionDataSto
 
     /**
      * Check a table's existence
-     * 
+     *
      * @param tableName The table name to check
      * @param dbmd The database's meta data
      * @return <code>true</code> if table exists; otherwise <code>false</code>
